@@ -1,11 +1,13 @@
 import binascii
 import collections
+import collections.abc
 import contextlib
 import functools
 import glob
 import io
 import itertools
 import json
+import keyword
 import os
 import platform
 import shutil
@@ -441,7 +443,7 @@ class MakeTextIO:
         sio (Optional[StringIO]): the I/O object to manage in the context
             only if :attr:`self.obj <MakeTextIO.obj>` is ``str``
         pos (Optional[int]): the original offset of :attr:`self.obj <MakeTextIO.obj>`,
-            only if :attr:`self.obj <MakeTextIO.obj>` is a *file* object
+            only if :attr:`self.obj <MakeTextIO.obj>` is a seekable *file* object
 
     """
 
@@ -652,14 +654,14 @@ def map_tasks(func, iterable, posargs=None, kwargs=None, *, processes=None, chun
         return [func(item, *posargs, **kwargs) for item in iterable]
 
     with mp.Pool(processes=processes or CPU_CNT) as pool:  # parallel execution
-        return pool.map(_mp_map_wrapper, [(func, (item,) + posargs, kwargs) for item in iterable], chunksize)
+        return pool.map(_mp_map_wrapper, [(func, (item,) + tuple(posargs), kwargs) for item in iterable], chunksize)
 
 
 #: A lock for possibly concurrent tasks.
 TaskLock = mp.Lock if parallel_available else nullcontext
 
 
-class Config:
+class Config(collections.abc.MutableMapping):
     """Configuration namespace.
 
     This class is inspired from :class:`argparse.Namespace` for storing
@@ -674,14 +676,32 @@ class Config:
     def __contains__(self, key):
         return key in self.__dict__
 
-    def __repr__(self):  # pragma: no cover
+    def __iter__(self):
+        return iter(self.__dict__)
+
+    def __len__(self):
+        return len(self.__dict__)
+
+    def __getitem__(self, key):
+        return self.__dict__[key]
+
+    def __setitem__(self, key, value):
+        self.__dict__[key] = value
+
+    def __delitem__(self, key):
+        del self.__dict__[key]
+
+    def __eq__(self, other):
+        return isinstance(other, Config) and self.__dict__ == other.__dict__
+
+    def __repr__(self):
         type_name = type(self).__name__
         arg_strings = []
         star_args = {}
-        for name, value in self.__dict__.items():
-            if name.isidentifier():  # special case
+        for name, value in sorted(self.__dict__.items()):
+            if name.isidentifier() and not keyword.iskeyword(name) and name != '__debug__':
                 arg_strings.append('%s=%r' % (name, value))
-            else:
+            else:  # wrap invalid names into a dict to make __repr__ round-trip
                 star_args[name] = value
         if star_args:
             arg_strings.append('**%s' % repr(star_args))
