@@ -1,5 +1,6 @@
 # pylint: disable=line-too-long
 
+import collections.abc
 import inspect
 import io
 import os
@@ -11,7 +12,6 @@ import tempfile
 import unittest
 
 import parso
-
 from bpc_utils import (
     LOOKUP_TABLE, PARSO_GRAMMAR_VERSIONS, BPCSyntaxError, Config, MakeTextIO, TaskLock,
     UUID4Generator, _mp_map_wrapper, archive_files, detect_encoding, detect_files,
@@ -431,7 +431,9 @@ class TestBPCUtils(unittest.TestCase):
     def test__mp_map_wrapper(self):
         self.success_cases = [
             SuccessCase(args=((square, (6,), {}),), result=36),
+            SuccessCase(args=((square, range(6, 7), {}),), result=36),  # pylint: disable=range-builtin-not-iterating
             SuccessCase(args=((int, ('0x10',), {'base': 16}),), result=16),
+            SuccessCase(args=((int, ('0x10',), Config(base=16)),), result=16),
         ]
         self.target_func = _mp_map_wrapper
         self.generic_functional_test()
@@ -442,7 +444,7 @@ class TestBPCUtils(unittest.TestCase):
             (square, range(1, 4), None, None, [1, 4, 9]),  # pylint: disable=range-builtin-not-iterating
             (divmod, [4, 7, 9], (3,), None, [(1, 1), (2, 1), (3, 0)]),
             (int, ['0x%c' % c for c in 'abc'], None, {'base': 0}, [10, 11, 12]),
-            (max, [4, -7, 9], (6,), {'key': abs}, [6, -7, 9]),
+            (max, [4, -7, 9], range(6, 7), Config(key=abs), [6, -7, 9]),  # pylint: disable=range-builtin-not-iterating
         ]
         self.success_cases = []
         for tc in test_cases:
@@ -467,13 +469,57 @@ class TestBPCUtils(unittest.TestCase):
 
     def test_Config(self):
         config = Config(foo='var', bar=True, boo=1)
-
+        self.assertIsInstance(config, collections.abc.MutableMapping)
         self.assertEqual(config.foo, 'var')  # pylint: disable=no-member
         self.assertEqual(config.bar, True)  # pylint: disable=no-member
         self.assertEqual(config.boo, 1)  # pylint: disable=no-member
+        self.assertEqual(config['foo'], 'var')
+        self.assertEqual(config['bar'], True)
+        self.assertEqual(config['boo'], 1)
+        self.assertTrue('foo' in config)
+        self.assertFalse('moo' in config)
+        self.assertFalse('666' in config)
+        self.assertEqual(len(config), 3)
+        self.assertEqual(repr(config), "Config(bar=True, boo=1, foo='var')")
 
-        self.assertEqual('foo' in config, True)
-        self.assertEqual('moo' in config, False)
+        config['666'] = '777'
+        self.assertTrue('666' in config)
+        self.assertEqual(config['666'], '777')
+
+        setattr(config, '666', '888')
+        self.assertEqual(config['666'], '888')
+
+        del config['666']
+        self.assertFalse('666' in config)
+
+        delattr(config, 'foo')
+        self.assertFalse('foo' in config)
+
+        del config.bar  # pylint: disable=no-member
+        self.assertFalse('bar' in config)
+        self.assertEqual(len(config), 1)
+        for key, value in config.items():
+            self.assertEqual(key, 'boo')
+            self.assertEqual(value, 1)
+
+        config.xxx = 'yyy'
+        self.assertTrue('xxx' in config)
+        self.assertEqual(config['xxx'], 'yyy')
+
+        self.assertEqual(dict(Config(a=1, b=2)), {'a': 1, 'b': 2})
+        self.assertEqual(Config(a=1, b=2), Config(b=2, a=1))
+        self.assertNotEqual(Config(a=1, b=2), {'a': 1, 'b': 2})
+        self.assertNotEqual(Config(a=1, b=2), Config(b=1, a=2))
+
+        self.assertEqual(repr(Config(**{'z': 1, 'y': '2'})), "Config(y='2', z=1)")
+        self.assertEqual(repr(Config(**{'z': True, '@': []})), "Config(z=True, **{'@': []})")
+        self.assertEqual(repr(Config(**{'z': (), '8': 2})), "Config(z=(), **{'8': 2})")
+        self.assertEqual(repr(Config(zz='zoo', **{'z': 1, 'return': 2})), "Config(z=1, zz='zoo', **{'return': 2})")
+        self.assertEqual(repr(Config(**{'z': 1, '__debug__': {}})), "Config(z=1, **{'__debug__': {}})")
+        self.assertEqual(repr(Config(**{'return': 0})), "Config(**{'return': 0})")
+        if sys.version_info[:2] >= (3, 6):  # dict preserves insertion order  # pragma: no cover
+            self.assertEqual(repr(Config(**{'z': 1, 'return': 2, '8': 3})), "Config(z=1, **{'8': 3, 'return': 2})")
+            self.assertEqual(repr(Config(**{'return': 0, '8': 3})), "Config(**{'8': 3, 'return': 0})")
 
 
 if __name__ == '__main__':
